@@ -72,7 +72,7 @@ class ProgrammingLanguage(abstract):
     The `TokenizableLanguage` of the language. 
     """
 
-    def __init__(self, name, tokenize_name = None):
+    def __init__(self, name: str, tokenize_name: str | None = None):
         self.name = name
         self.language = getattr(tokenize_all, tokenize_name if tokenize_name else name)
         self.color = language_colors[name]["color"]
@@ -126,11 +126,11 @@ class CodeBlock(VGroup):
             - Additional arguments passed to `VGroup`.
         """
 
-        lines = text.split("\n")
-        group_count = 0
-        finished: list[str] = []
-        for line in lines:
-            if language: 
+        if language:
+            lines = text.split("\n")
+            group_count = 0
+            finished: list[str] = []
+            for line in lines:
                 tokens = language.language.tokenize(line)
                 for token in tokens:
                     if token.type.startswith('left'):
@@ -142,12 +142,13 @@ class CodeBlock(VGroup):
                     elif token.type == "whitespace": finished.append(token.value)
                     else: finished.append('<span foreground="' + theme.color_for(token = token) + '">' + token.value + '</span>')
                 finished.append("\r")
-            else:
 
-        finished_text = "".join(finished)
-        finished_text = regex.sub("&", "&amp;", finished_text)
-        finished_text = regex.sub("><<", ">&lt;<", finished_text)
-        finished_text = regex.sub(">><", ">&gt;<", finished_text)
+            finished_text = "".join(finished)
+            finished_text = regex.sub("&", "&amp;", finished_text)
+            finished_text = regex.sub("><<", ">&lt;<", finished_text)
+            finished_text = regex.sub(">><", ">&gt;<", finished_text)
+        else:
+            finished_text = '<span foreground="#FFFFFF">' + text + "</span>"
 
         markup = MarkupText(f'<span font="{font}">' + finished_text + '</span>', z_index = 3).scale(0.4)
         background_rect = BackgroundRectangle(
